pub struct CapabilityStore { /* private fields */ }Expand description
A wrapper over fsandbox::CapabilityStoreProxy providing self-contained types.
Implementations
Sourceimpl<'a> CapabilityStore
impl<'a> CapabilityStore
Sourcepub fn connect() -> Result<Self, Error>
pub fn connect() -> Result<Self, Error>
Connects to the fuchsia.component.sandbox/CapabilityStore protocol.
Sourcepub async fn import<T>(&'a self, value: T) -> Result<T::Ref, Error>where
T: Importable<'a>,
pub async fn import<T>(&'a self, value: T) -> Result<T::Ref, Error>where
T: Importable<'a>,
Imports a capability into the store.
Sourcepub async fn create_dictionary(&'a self) -> Result<Dictionary<'a>, Error>
pub async fn create_dictionary(&'a self) -> Result<Dictionary<'a>, Error>
Creates a new, empty dictionary in the capability store.
Sourcepub async fn create_connector(
&'a self,
client_end: ClientEnd<ReceiverMarker>,
) -> Result<Connector<'a>, Error>
pub async fn create_connector( &'a self, client_end: ClientEnd<ReceiverMarker>, ) -> Result<Connector<'a>, Error>
Creates a new Connector capability from a Receiver client end.
Sourcepub async fn create_dir_connector(
&'a self,
client_end: ClientEnd<DirReceiverMarker>,
) -> Result<DirConnector<'a>, Error>
pub async fn create_dir_connector( &'a self, client_end: ClientEnd<DirReceiverMarker>, ) -> Result<DirConnector<'a>, Error>
Creates a new DirConnector capability from a DirReceiver client end.